@@ -56,7 +56,6 @@ def _stub_volume(*args, **kwargs):
         "metadata": {},
         "status": "available",
         'description': None,
-        "multiattach": "false",
         "os-volume-replication:driver_data": None,
         "source_volid": None,
         "consistencygroup_id": None,
@@ -310,6 +309,30 @@ def _stub_server_versions():
     ]
 
 
+def stub_default_type():
+    return {
+        'default_type': {
+            'project_id': '629632e7-99d2-4c40-9ae3-106fa3b1c9b7',
+            'volume_type_id': '4c298f16-e339-4c80-b934-6cbfcb7525a0'
+        }
+    }
+
+
+def stub_default_types():
+    return {
+        'default_types': [
+            {
+                'project_id': '629632e7-99d2-4c40-9ae3-106fa3b1c9b7',
+                'volume_type_id': '4c298f16-e339-4c80-b934-6cbfcb7525a0'
+            },
+            {
+                'project_id': 'a0c01994-1245-416e-8fc9-1aca86329bfd',
+                'volume_type_id': 'ff094b46-f82a-4a74-9d9e-d3d08116ad93'
+            }
+        ]
+    }
+
+
 class FakeClient(fakes.FakeClient, client.Client):
 
     def __init__(self, api_version=None, *args, **kwargs):
@@ -389,9 +412,12 @@ class FakeHTTPClient(base_client.HTTPClient):
     #
 
     def get_snapshots_detail(self, **kw):
+        if kw.get('with_count', False):
+            return (200, {}, {'snapshots': [
+                _stub_snapshot(),
+            ], 'count': 1})
         return (200, {}, {'snapshots': [
-            _stub_snapshot(),
-        ]})
+            _stub_snapshot()]})
 
     def get_snapshots_1234(self, **kw):
         return (200, {}, {'snapshot': _stub_snapshot(id='1234')})
@@ -464,6 +490,10 @@ class FakeHTTPClient(base_client.HTTPClient):
             ]})
 
     def get_volumes_detail(self, **kw):
+        if kw.get('with_count', False):
+            return (200, {}, {"volumes": [
+                _stub_volume(id=kw.get('id', 1234))
+            ], "count": 1})
         return (200, {}, {"volumes": [
             _stub_volume(id=kw.get('id', 1234))
         ]})
@@ -524,10 +554,6 @@ class FakeHTTPClient(base_client.HTTPClient):
             assert list(body[action]) == ['bootable']
         elif action == 'os-unmanage':
             assert body[action] is None
-        elif action == 'os-promote-replica':
-            assert body[action] is None
-        elif action == 'os-reenable-replica':
-            assert body[action] is None
         elif action == 'os-set_image_metadata':
             assert list(body[action]) == ['metadata']
         elif action == 'os-unset_image_metadata':
@@ -543,6 +569,15 @@ class FakeHTTPClient(base_client.HTTPClient):
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
 
+    def get_volumes_fake(self, **kw):
+        r = {'volume': self.get_volumes_detail(id='fake')[2]['volumes'][0]}
+        return (200, {}, r)
+
+    def post_volumes_fake_action(self, body, **kw):
+        _body = None
+        resp = 202
+        return (resp, {}, _body)
+
     def post_volumes_5678_action(self, body, **kw):
         return self.post_volumes_1234_action(body, **kw)
 
@@ -678,10 +713,8 @@ class FakeHTTPClient(base_client.HTTPClient):
 
     def put_os_quota_class_sets_test(self, body, **kw):
         assert list(body) == ['quota_class_set']
-        fakes.assert_has_keys(body['quota_class_set'],
-                              required=['class_name'])
+        fakes.assert_has_keys(body['quota_class_set'])
         return (200, {}, {'quota_class_set': {
-                          'class_name': 'test',
                           'volumes': 2,
                           'snapshots': 2,
                           'gigabytes': 1,
@@ -878,6 +911,12 @@ class FakeHTTPClient(base_client.HTTPClient):
         tenant_id = '0fa851f6668144cf9cd8c8419c1646c1'
         backup1 = '76a17945-3c6f-435c-975b-b5685db10b62'
         backup2 = 'd09534c6-08b8-4441-9e87-8976f3a8f699'
+        if kw.get('with_count', False):
+            return (200, {},
+                    {'backups': [
+                        _stub_backup_full(backup1, base_uri, tenant_id),
+                        _stub_backup_full(backup2, base_uri, tenant_id)],
+                    'count': 2})
         return (200, {},
                 {'backups': [
                     _stub_backup_full(backup1, base_uri, tenant_id),
@@ -1040,9 +1079,35 @@ class FakeHTTPClient(base_client.HTTPClient):
                 {'transfer': _stub_transfer(transfer1, base_uri, tenant_id)})
 
     def get_with_base_url(self, url, **kw):
+        if 'default-types' in url:
+            return self._cs_request(url, 'GET', **kw)
         server_versions = _stub_server_versions()
         return (200, {'versions': server_versions})
 
+    def create_update_with_base_url(self, url, **kwargs):
+        return self._cs_request(url, 'PUT', **kwargs)
+
+    def put_v3_default_types_629632e7_99d2_4c40_9ae3_106fa3b1c9b7(
+            self, **kwargs):
+        default_type = stub_default_type()
+        return (200, {}, default_type)
+
+    def get_v3_default_types_629632e7_99d2_4c40_9ae3_106fa3b1c9b7(
+            self, **kw):
+        default_types = stub_default_type()
+        return (200, {}, default_types)
+
+    def get_v3_default_types(self, **kw):
+        default_types = stub_default_types()
+        return (200, {}, default_types)
+
+    def delete_with_base_url(self, url, **kwargs):
+        return self._cs_request(url, 'DELETE', **kwargs)
+
+    def delete_v3_default_types_629632e7_99d2_4c40_9ae3_106fa3b1c9b7(
+            self, **kwargs):
+        return (204, {}, {})
+
     #
     # Services
     #
@@ -1221,12 +1286,6 @@ class FakeHTTPClient(base_client.HTTPClient):
         snapshot.update(kw['body']['snapshot'])
         return (202, {}, {'snapshot': snapshot})
 
-    def post_os_promote_replica_1234(self, **kw):
-        return (202, {}, {})
-
-    def post_os_reenable_replica_1234(self, **kw):
-        return (202, {}, {})
-
     def get_scheduler_stats_get_pools(self, **kw):
         stats = [
             {
@@ -1258,9 +1317,9 @@ class FakeHTTPClient(base_client.HTTPClient):
                 'storage_protocol': 'iSCSI',
                 'properties': {
                     'compression': {
-                        'title': 'Compression',
-                        'description': 'Enables compression.',
-                        'type': 'boolean'},
+                        u'title': u'Compression',
+                        u'description': u'Enables compression.',
+                        u'type': u'boolean'},
                 }
             }
         )
